Automodulesumm of dummy test module without signatures
======================================================

.. automodulesumm:: dummy
    :no-members:
    :autosummary-members:
    :autosummary-nosignatures:
